**Example 1: 请求示例**



Input: 

```
tccli redis DeleteReplicationInstance --cli-unfold-argument  \
    --InstanceId crs-sa5dsfs \
    --SyncType True \
    --GroupId crs-rpl-sa5dsfs
```

Output: 
```
{
    "Response": {
        "RequestId": "c4ed5948-d156-4931-b9c3-10133a0bb6c9",
        "TaskId": 10856
    }
}
```

